# Awesome Decentralized Web [![Awesome](https://cdn.rawgit.com/sindresorhus/awesome/d7305f38d29fed78fa85652e3a63e154dd8e8829/media/badge.svg)](https://github.com/sindresorhus/awesome)

A curated list about the decentralized technologies and tools to develop decentralized applications.  
Thanks to the [Decentralized Web Summit](https://www.decentralizedweb.net/) for the inspiration.

Projects inactive for a while are marked as **discontinued!**.

## Protocols and Technologies
*Tools for building a decentralized web.*


### Communication
* [ForgeFed](https://github.com/forgefed/forgefed) - a decentralized federation protocol provides a server to server API for pull request, forking and subscription.
* [Matrix](https://matrix.org/) - an open standard for decentralised persistent communication over IP. Matrix wants to connect together all the various communication services and make them interoperate.
* [Scuttlebutt](https://www.scuttlebutt.nz/) - a decent(ralised), offline-friendly secure gossip protocol.

### Data
* [BitTorrent](https://en.wikipedia.org/wiki/BitTorrent) - protocol for distributed file sharing.
* [Earthstar](https://github.com/earthstar-project/earthstar) - An offline-first, distributed, syncable, embedded document database for use in p2p software.
* [Hypercore Protocol](https://hypercore-protocol.org/) - a fast, scalable, and secure peer-to-peer protocol for everyone (evoution of the [Dat Protocol](https://datproject.org))
* [Holochain](https://github.com/holochain/holochain) - a peer-to-peer protocol for data sharing and integrity, backed by authoritative hashchains for data provenance.
* [IPFS](https://ipfs.io/) - or InterPlanetary File System, is a distributed file storage system that aims to replace HTTP.

### Web
* [ActivityPub](https://www.w3.org/TR/activitypub/) - open, decentralized social networking protocol based on Pump.io's ActivityPump protocol.
* [Blockstack](https://blockstack.org/) - Blockstack is a new fully decentralized internet that comes with a full stack of open-source developer tools to build and bootstrap decentralized applications and protocol ecosystems.
* [Interledger](https://interledger.org/) - it interconnects disparate cryptocurrencies and financial systems.
* [libdweb](https://github.com/mozilla/libdweb) - a community effort to implement experimental APIs enabling dweb protocols in Firefox.
* [Mysterium Network](https://mysterium.network/) - open sourced network allowing anyone to rent their unused Network traffic, while providing a secure connection for those in need. `Whitepaper`
* [Solid](https://solid.mit.edu/) - a proposed set of conventions and tools for building decentralized social applications based on Linked Data principles.
* [Webnative](https://fission.codes/) - JavaScript library that decouples user data from apps and hosts it on IPFS.
* [WebRTC](https://en.wikipedia.org/wiki/WebRTC) - W3C drafted standard for browser-to-browser data transfer.


## Applications
*Things built with decentralized protocols and technologies.*


### Collaboration
* [Backfeed](http://backfeed.cc/) - a technology to enable decentralized and user-owned governance and reputation management for a community. **Discontinued!**
* [bitnation.co](https://bitnation.co) - the World’s First Virtual Nation – A Blockchain Jurisdiction.
* [git-ssb](https://github.com/clehner/git-ssb) - Decentralized git repo hosting and issue tracking on secure-scuttlebutt.
* [PeerPad](https://peerpad.net) - a realtime P2P collaborative editing tool, powered by IPFS and CRDTs.
* [Radicle](https://radicle.xyz/) - secure peer-to-peer code collaboration without intermediaries.

### Communication
* [BitMessage](https://bitmessage.org/wiki/Main_Page) - anonymous encrypted message broadcasting.
* [Berty](https://github.com/berty/berty) - anonymous, secure, peer-to-peer protocol that doesn't need an internet connection to function.
* [disaster.radio](https://disaster.radio) - a disaster-resilient communications network powered by the sun.
* [LevelNews](https://levelnews.org/) - a leftist news aggregator designed for an open web, and dedicated to journalism without censorship.
* [LibreMesh](https://libremesh.org/) - a modular framework for creating OpenWrt/LEDE-based firmwares for wireless mesh nodes.
* [Mobilizon](https://joinmobilizon.org/) -  a federated tool that helps you find, create and organise events.
* [Retroshare](https://retroshare.cc/) -  establish encrypted connections between you and your friends to create a network of computers, and provides various distributed services: forums, channels, chat, mail
* [Ricochet](https://ricochet.im/) - completely anonymous and potentially metadata-free chat **Discontinued!**

### Cryptocurrencies
* [Bitcoin](https://bitcoin.org) - it is the first decentralized digital currency, as the system works without a central bank or single administrator.
* [Ethereum](https://ethereum.org) - blockchain-based distributed computing platform featuring smart contract (scripting) functionality. It provides a decentralized Turing-complete virtual machine
* [Monero](https://getmonero.org/) - aims to improve on existing cryptocurrency design by obscuring sender, recipient and amount of every transaction.
* [Zcash](https://z.cash/) - a cryptocurrency built for total privacy. Zcash encrypts transactions so that they can be validated while still private.
* [Awesome-cryptocurrencies](https://github.com/kasketis/awesome-cryptocurrencies) - a curated list of cryptocurrencies.
* [Curated list of blockchain and crytocurrency resources in general](https://github.com/McFrankline/Blockchain-stuff)

### Databases
* [BigchainDB](https://www.bigchaindb.com/) - a scalable database that layers blockchain technology over decentralized data.
* [Dat Base](https://datbase.org) - future-friendly apps for your research data pipeline.
* [GUN](https://www.gun.eco) - a small, easy, and fast data sync and storage system that runs everywhere JavaScript does.
* [IPDB](https://ipdb.io/) - a federated database network built on BigchainDB and IPFS. It is maintained by a network of caretakers around the world, at least half of which are nonprofits.
* [OrbitDB](https://github.com/orbitdb/orbit-db) - p2p database engine on top of IPFS.
* [AvionDB](https://github.com/dappkit/aviondb) - mongodb-like database on top of OrbitDB.

### Data Storage and Sharing
* [Arweave](https://www.arweave.org/) - A Protocol for Economically SustainableInformation Permanence.
* [CacheP2P](https://github.com/guerrerocarlos/CacheP2P) - a distributed caching platform. **Discontinued!**
* [Cryptosphere](https://cryptosphere.io/) - an open-source P2P web application platform for decentralized, privacy-preserving software. **Discontinued!**
* [Filecoin](https://filecoin.io/) - a decentralized storage network based on IPFS, powered by a blockchain and a native token. `Whitepaper`
* [instant.io](https://instant.io/) - streaming file transfer over WebTorrent.
* [OnionShare](https://onionshare.org/) - hosts the selected files as a hidden service on the user's computer
* [ORC](https://orcproject.github.io/) - the Onion Router Cloud, a distributed, anonymous, object storage platform owned and operated by all of us. **Discontinued!**
* [Peergos](https://peergos.org/) - end-to-end encrypted, peer-to-peer file storage, sharing and communication network.
* [Perkeep](https://perkeep.org/) - set of open source formats, protocols, and software for modeling, storing, searching, sharing and synchronizing data.
* [Rotonde](https://wiki.xxiivv.com/#rotonde) - commonly agreed upon specifications of a JSON object shared between members of the network.
* [Tahoe-LAFS](https://www.tahoe-lafs.org/trac/tahoe-lafs) - a private, encrypted file storage system that decentralizes data across multiple servers.
* [Tribler](https://www.tribler.org) - Privacy enhanced BitTorrent client with P2P content discovery.
* [Sia](https://sia.tech/) - a decentralized private cloud. `Whitepaper`
* [Storj](https://storj.io/) - a blockchain-based, end-to-end encrypted, distributed object storage. `Whitepaper`
* [Swarm](https://github.com/ethersphere/swarm) - a distributed storage platform and content distribution service of the ethereum stack.
* [WebTorrent](https://webtorrent.io/) - an in-browser torrenting that works without requiring users to install anything extra.
* [Wikipediap2p](https://guerrerocarlos.github.io/WikiP2P.org/) - a p2p version of wikipedia. **Discontinued!**

### Media
* [Bit451](https://github.com/Bit451/Bit451) - decentralized / distributed anonymous p2p media network. YouTube meets BitTorrent meets Bitcoin. **Discontinued!**
* [DTube](https://d.tube/) - decentralized video platform, built on top of the STEEM Blockchain and the IPFS peer-to-peer network.
* [ferment](https://github.com/fermentation/ferment) - Peer-to-peer audio publishing and streaming application.
* [Mediachain](http://www.mediachain.io/) -  a media library built on IPFS that makes it easy to publish, track, and discover creative work.
* [Mediagoblin](https://mediagoblin.org/) - a free software media publishing platform alternative to Flickr, YouTube, SoundCloud.
* [PeerTube](https://framagit.org/chocobozzz/PeerTube) - Decentralized federated video streaming platform using P2P, ActivityPub and WebTorrent.
* [Funkwhale](https://funkwhale.audio/) - Funkwhale is a community-driven project that lets you listen and share music and audio within a decentralized, open network.

### Microblogging and Social Network
* [Dat Medium](https://github.com/kewitz/dat-medium) - Dat Medium is markdown blog system for Beaker inspired by Medium. **Discontinued!**
* [diaspora*](https://diasporafoundation.org/) - decentralized and federated social media platform.
* [Friendica](https://friendi.ca/) - decentralized and federated social media platform.
* [Hubzilla](https://zotlabs.org/page/hubzilla/hubzilla-project) - decentralized and federated social media platform.
* [Mastodon](https://mastodon.social) - decentralized alternative to twitter, with servers federation.
* [Patchwork](https://github.com/ssbc/patchwork) - a decentralized messaging and sharing app built on top of Secure Scuttlebutt.
* [Manyverse](https://www.manyver.se/) - An iOS and Android mobile app for the decentralized messaging and sharing app built on top of Secure Scuttlebutt
* [Pleroma](https://pleroma.social/) - a federated social networking platform.
* [Socialhome](https://socialhome.network/) - decentralized and federated profile builder with social networking features.
* [Tahrir](http://tahrirproject.org/) - looks and feels like twitter but encrypted and anonymized and decentralized and only you hold the keys. **Discontinued!**
* [trsst](https://github.com/TrsstProject/trsst) - looks and feels like twitter but encrypted and anonymized and decentralized and only you hold the keys. **Discontinued!**
* [Twister](http://twister.net.co/) - a fully decentralized P2P microblogging platform leveraging the free software implementations of Bitcoin and BitTorrent protocols.

### Miscellaneous
* [Jolocom](https://jolocom.com/) - a decentralised digital identity for everyone.
* [magic-wormhole](https://github.com/warner/magic-wormhole) - get things from one computer to another, safely.
* [OpenTimeStamps](https://opentimestamps.org/) - OpenTimestamps aims to be a standard format for blockchain timestamping.
* [StrongLink](https://github.com/btrask/stronglink) - a searchable, syncable, content-addressable notetaking system **Discontinued!**
* [Dark Crystal](https://darkcrystal.pw/) - set of protocols, libraries, techniques and guidelines for secure management of sensitive data such as cryptographic keys.

### Web
* [Agregore](https://agregore.mauve.moe/) - A minimal web browser for the distributed web. Supports IPFS, Hypercore Protocol + more.
* [Beaker](https://beakerbrowser.com/) - Beaker is a peer-to-peer Web browser, made for users to run applications independently of hosts.
* [Freenet](https://freenetproject.org/)- a network aimed at activists and people living in repressive regimes. It uses a web of trust in high security mode, which allows users on the network to be effectively undetectable.
* [GNUnet](https://gnunet.org/) - GNUnet is a new network protocol stack for building secure, distributed, and privacy-preserving applications. With strong roots in academic research, our goal is to replace the old insecure Internet protocol stack.
* [Handshake](https://handshake.org/) - decentralized certificate authority and naming.
* [I2P](https://geti2p.net/) - anonymous network with hidden services.
* [IPWB](https://github.com/oduwsdl/ipwb) - an interplanetary wayback machine.
* [Loki](https://loki.network/) - Loki creates privacy tools that enable untraceable, secure transactions and anonymous communication.
* [MaidSafe](https://maidsafe.net/) - a soon-to-be-released decentralized internet and app infrastructure which rewards users for participating in the network.
* [Namecoin](https://namecoin.info/) - a replacement for the existing domain name system that registers identities on a blockchain, rather than a centralized DNS authority.
* [Onename](https://onename.com/) - domain registar for Blockstack.
* [OpenBazaar](https://openbazaar.org/) - marketplace, with store fronts and moderators.
* [Samizdat](http://samizdat.childrenofmay.org/) - Samizdat is a platform for the self-hosted, peer-to-peer, cryptographically-secured internet. **Discontinued!**
* [Shift](https://www.shiftnrg.org) - Decentralized hosting infrastructure for dApps.
* [Steemit](https://steemit.com/) - blogging and social networking website on top of a blockchain database.      
* [Tor](https://www.torproject.org/) - anonymous network proxy.
* [yacy](https://github.com/yacy/yacy_search_server) - Distributed Peer-to-Peer Web Search Engine and Intranet Search Appliance.
* [ZeroNet](https://zeronet.io/) - a peer-to-peer web built on the Bitcoin cryptography for addressing, and identity and Namecoin for .bit domains.
* [ArcBlock](https://www.arcblock.io/) - a decentralized platform to build, run and deploy DApps, blockchains and websites on any infrastructure with integrated decentralized identity and multi-chain support.

## Other Related Lists
* [Awesome-decentralized-id](https://github.com/infominer33/awesome-decentralized-id) - Resources for creating a Decentralized, Vendor Agnostic, Self Sovereign Identity System for people organizations and things.

## Contributors
- [Contributors](https://github.com/gdamdam/awesome-decentralized-web/graphs/contributors)


## License
 [![CC4](https://i.creativecommons.org/l/by-sa/4.0/88x31.png)](https://creativecommons.org/licenses/by-sa/4.0/)
